package mobicomp.hearts.lobby;

import java.io.Serializable;
import java.util.Iterator;
import java.util.Vector;

import mobicomp.hearts.data.Player;

/**
 * @author Andreas Wetzel <andi@spamato.net>
 * Last Update 8.1.2005 Nicolas
 */
public class Game implements Serializable
{
    private Vector players = new Vector(); // all players who have joined the group. The fist player is the host.
    private boolean hasStarted;
    
    public Game(Player player) {
        players.add(player);
    }
    
    /**
     * Returns the Player object of the player hosting the group
     * @return The Player hosting the game
     */
    public Player getHostPlayer() {
        return (Player)players.get(0);
    }
    
    /**
     * @return The vector containing all players
     */
    public Vector getPlayers() {
    	return players;
    }
    /**
     * Adds a new player to the group
     * @param player the player to add
     * @return true if the player could be added or is a member of the group. 
     */
    public synchronized boolean addPlayer( Player player) {
    	if (players.contains(player)){ return true; } // the player is already in the game
    	
    	if (hasStarted){ return false; } // the game is already running 
    	
        if (players.size() < 4) { 	// it's a new player and there is room enough for at least one more
            players.add(player);
            return true;
        }
        return false;
    }
    
    /**
     * Removes the player from the group
     * @param player The player to remove
     */
    public void removePlayer(Player player) {
        players.remove(player);
    }
    
    
   /**
    * called to start the game
    */
    public void setStarted() {
        hasStarted = true;
    }
    
    /**
     * Returns if the game is started
     * @return true if the game is running
     */
    public boolean isStarted(){
    	return isStarted();
    }
    
    /**
     * Prints the actual state of the game. The number of players
     * and their names
     * @return Info String
     */
    public String getInfo() {
        String info = new String("Waiting for "+ (4-players.size()) +" more player");
        if (players.size()<3){ info +=  "s"; }     
        info += "\nPlayers: ";
       
        Iterator it = players.iterator();
        while (it.hasNext()){
            Player cur = (Player) it.next();
            info +=  cur.getName();
            if (it.hasNext()) {
                info += ", ";
            }
        }
        return info;
    }
    
    public String toString() {
    	return getHostPlayer().getName() + " (" + players.size() + "/4)";
    }
}
